@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -32,7 +32,7 @@ from textwrap import dedent
 from unittest import TestCase
 
 import requests
-from mock import Mock, patch
+from unittest.mock import Mock, patch
 from mailman.config import config
 from mailman.email.message import Message
 from mailman.testing.layers import ConfigLayer
@@ -161,6 +161,13 @@ Not really HTML
             headers={'Authorization': 'Token DummyKey'},
             )
 
+    def test_list_url_raises_exception(self):
+        # Test that any exceptions raised by requests is caught.
+        old = self.requests.get.side_effect
+        self.requests.get.side_effect = requests.exceptions.SSLError()
+        self.assertEqual(self.archiver.list_url(self.mlist), "")
+        self.requests.get.side_effect = old
+
     def test_permalink(self):
         msg = self._get_msg()
         url = ("http://example.com/list/list@lists.example.com/"
@@ -188,7 +195,7 @@ Not really HTML
             "http://localhost/api/mailman/archive",
             headers={'Authorization': 'Token DummyKey'},
             data={'mlist': 'list@lists.example.com'},
-            files={'message': ('message.txt', msg.as_string())},
+            files={'message': ('message.txt', msg.as_bytes())},
         )
         # Check that the archive directory was created.
         self.assertTrue(os.path.exists(
@@ -212,7 +219,8 @@ Not really HTML
             "http://localhost/api/mailman/archive",
             headers={'Authorization': 'Token DummyKey'},
             data={'mlist': 'list@lists.example.com'},
-            files={'message': ('message.txt', _sanitize(msg.as_string()))},
+            files={'message': ('message.txt',
+                               _sanitize(msg.as_string()).encode('utf-8'))},
         )
         # Check that the archive directory was created.
         self.assertTrue(os.path.exists(
@@ -253,9 +261,9 @@ Not really HTML
         with patch("mailman_hyperkitty.logger") as logger:
             self.archiver.archive_message(self.mlist, self._get_msg())
         # Check error log
-        self.assertEqual(logger.error.call_count, 3)
+        self.assertEqual(logger.error.call_count, 5)
         self.assertTrue(isinstance(
-            logger.error.call_args_list[1][0][1], ValueError))
+            logger.error.call_args_list[3][0][1], ValueError))
         # Check that the message is stored in the spool.
         self.assertEqual(len(os.listdir(
             self.archiver._switchboard.queue_directory)), 1)
@@ -318,12 +326,12 @@ Not really HTML
                 (("http://localhost/api/mailman/archive",), dict(
                     headers={'Authorization': 'Token DummyKey'},
                     data={'mlist': 'list@lists.example.com'},
-                    files={'message': ('message.txt', msg_1.as_string())},
+                    files={'message': ('message.txt', msg_1.as_bytes())},
                 )),
                 (("http://localhost/api/mailman/archive",), dict(
                     headers={'Authorization': 'Token DummyKey'},
                     data={'mlist': 'list@lists.example.com'},
-                    files={'message': ('message.txt', msg_2.as_string())},
+                    files={'message': ('message.txt', msg_2.as_bytes())},
                 )),
             ])
         # Make sure the spool directory is empty now.
@@ -339,10 +347,10 @@ Not really HTML
         with patch("mailman_hyperkitty.logger") as logger:
             self.archiver.process_queue()
         # Check error log
-        self.assertEqual(logger.error.call_count, 3)
+        self.assertEqual(logger.error.call_count, 5)
         self.assertEqual(logger.error.call_args_list[0][0][3], 500)
         self.assertTrue(isinstance(
-            logger.error.call_args_list[1][0][1], ValueError))
+            logger.error.call_args_list[3][0][1], ValueError))
         # Check that the message is still stored in the spool.
         self.assertEqual(len(os.listdir(
             self.archiver._switchboard.queue_directory)), 1)
@@ -373,13 +381,13 @@ Not really HTML
         self.archiver._switchboard.enqueue.side_effect = OSError('Oops!')
         with patch("mailman_hyperkitty.logger") as logger:
             self.archiver.process_queue()
-        self.assertEqual(logger.error.call_count, 6)
+        self.assertEqual(logger.error.call_count, 8)
         # Check error log
         self.assertEqual(logger.error.call_args_list[0][0][3], 500)
         self.assertTrue(isinstance(
-            logger.error.call_args_list[1][0][1], ValueError))
+            logger.error.call_args_list[3][0][1], ValueError))
         self.assertTrue(isinstance(
-            logger.error.call_args_list[3][0][1], OSError))
+            logger.error.call_args_list[5][0][1], OSError))
         # Check that the message has been preserved for analysis
         self.assertEqual(len(glob.glob(os.path.join(
             config.switchboards["bad"].queue_directory, "*.psv")
